From 1b40b5e4c9b86de21255de663a980f397fc1cd3e Mon Sep 17 00:00:00 2001
From: curt <curt>
Date: Mon, 3 Feb 2003 22:22:02 +0000
Subject: [PATCH] Fixed a spelling error in the api. (ouch) :-)

---
 src/Systems/electrical.cxx | 12 ++++++------
 src/Systems/electrical.hxx |  2 +-
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/src/Systems/electrical.hxx b/src/Systems/electrical.hxx
index 30c3cc33c..3b20d298c 100644
--- a/src/Systems/electrical.hxx
+++ b/src/Systems/electrical.hxx
@@ -204,7 +204,7 @@ public:
     virtual void update (double dt);
 
     bool build ();
-    void propogate( FGElectricalComponent *node, double val, string s = "" );
+    void propagate( FGElectricalComponent *node, double val, string s = "" );
     FGElectricalComponent *find ( const string &name );
 
 protected:
diff --git a/src/Systems/electrical.cxx b/src/Systems/electrical.cxx
index 2559874ca..240a79868 100644
--- a/src/Systems/electrical.cxx
+++ b/src/Systems/electrical.cxx
@@ -301,10 +301,10 @@ void FGElectricalSystem::update (double dt) {
         connectors[i]->set_value( 0.0 );
     }
 
     // for each supplier, propogate the electrical current
     for ( i = 0; i < suppliers.size(); ++i ) {
         // cout << " Updating: " << suppliers[i]->get_name() << endl;
-        propogate( suppliers[i], 0.0, " " );
+        propagate( suppliers[i], 0.0, " " );
     }
 
 }
@@ -346,8 +346,8 @@ bool FGElectricalSystem::build () {
 }
 
 
-// propogate the electrical current through the network
-void FGElectricalSystem::propogate( FGElectricalComponent *node, double val,
+// propagate the electrical current through the network
+void FGElectricalSystem::propagate( FGElectricalComponent *node, double val,
                                     string s ) {
     s += " ";
 
@@ -388,9 +388,9 @@ void FGElectricalSystem::propogate( FGElectricalComponent *node, double val,
     }
     // cout << s << node->get_name() << " -> " << node->get_value() << endl;
 
     // propogate to all children
     for ( i = 0; i < node->get_num_outputs(); ++i ) {
-        propogate( node->get_output(i), current, s );
+        propagate( node->get_output(i), current, s );
     }
 }
 
@@ -301,10 +301,10 @@ void FGElectricalSystem::update (double dt) {
     }
 
-    // for each supplier, propogate the electrical current
+    // for each supplier, propagate the electrical current
     for ( i = 0; i < suppliers.size(); ++i ) {
         // cout << " Updating: " << suppliers[i]->get_name() << endl;
@@ -388,9 +388,9 @@ void FGElectricalSystem::propogate( FGElectricalComponent *node, double val,
     // cout << s << node->get_name() << " -> " << node->get_value() << endl;
 
-    // propogate to all children
+    // propagate to all children
     for ( i = 0; i < node->get_num_outputs(); ++i ) {